"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
const Messages_1 = require("./doc/Messages");
/**
 * Validate DB2 input parameters
 * @class SessionValidator
 * @export
 */
class SessionValidator {
    /**
     * Validate DB2 parameters
     * @static
     * @param {IDB2Session} params
     * @memberof SessionValidator
     */
    static validate(params) {
        imperative_1.ImperativeExpect.toNotBeNullOrUndefined(params, Messages_1.noDB2Input.message);
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(params.hostname, Messages_1.noHostName.message);
        imperative_1.ImperativeExpect.toNotBeNullOrUndefined(params.port, Messages_1.noPortNumber.message);
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(params.username, Messages_1.noUserName.message);
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(params.password, Messages_1.noPassword.message);
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(params.database, Messages_1.noDatabaseName.message);
    }
}
exports.SessionValidator = SessionValidator;
//# sourceMappingURL=SessionValidator.js.map