import { AbstractSession, ICommandHandler, IHandlerParameters } from "@brightside/imperative";
/**
 * This class is used by the various DB2 handlers as the base class for their implementation.
 * All handlers should extend this class whenever possible
 */
export declare abstract class DB2BaseHandler implements ICommandHandler {
    /**
     * Full set of command handler parameters from imperative
     */
    protected mHandlerParams: IHandlerParameters;
    /**
     * This will create a session before calling the subclass
     *
     * @param {IHandlerParameters} commandParameters Command parameters sent by imperative.
     *
     * @returns {Promise<void>}
     */
    process(commandParameters: IHandlerParameters): Promise<void>;
    /**
     * This is called by the {@link DB2BaseHandler#process} after it creates a session. Should
     * be used so that every class does not have to instantiate the session object.
     *
     * @param {IHandlerParameters} commandParameters Command parameters sent to the handler.
     * @param {AbstractSession} session The session object generated from the Command Line.
     *
     * @returns {Promise<void>} The response from the underlying DB2 api call.
     */
    abstract processWithDB2Session(commandParameters: IHandlerParameters, session: AbstractSession): Promise<void>;
}
