"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
const index_1 = require("../../../index");
const fs = require("fs");
/**
 * Command handler for exporting a DB2 table
 * @export
 * @class TableHandler
 * @implements {ICommandHandler}
 */
class TableHandler extends index_1.DB2BaseHandler {
    processWithDB2Session(params, session, profile) {
        return __awaiter(this, void 0, void 0, function* () {
            const DB2session = session.ISession;
            let [database, table] = params.arguments.table.split(".");
            if (table === null) {
                table = database;
                database = DB2session.database;
            }
            let outFile;
            if (params.arguments.outfile) {
                try {
                    outFile = fs.openSync(params.arguments.outfile, "w");
                }
                catch (err) {
                    throw new imperative_1.ImperativeError({ msg: err.toString() });
                }
            }
            const sqlExporter = new index_1.ExportTableSQL(DB2session, database, table);
            yield sqlExporter.init();
            const statements = sqlExporter.export();
            let statement;
            while (!(statement = statements.next()).done) {
                if (params.arguments.outfile) {
                    // Write statements to a file
                    fs.writeSync(outFile, statement.value);
                }
                else {
                    // Print out the response
                    params.response.console.log(statement.value);
                }
            }
            if (params.arguments.outfile) {
                fs.closeSync(outFile);
            }
        });
    }
}
exports.default = TableHandler;
//# sourceMappingURL=Table.handler.js.map